#if !defined(AFX_SETTINGGENERALOTHERDLG_H__2D070D89_4B2B_4B11_8A74_ADAFE9D50F74__INCLUDED_)
#define AFX_SETTINGGENERALOTHERDLG_H__2D070D89_4B2B_4B11_8A74_ADAFE9D50F74__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// SettingGeneralOtherDlg.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CSettingGeneralOtherDlg _CAO

class CSettingGeneralOtherDlg : public CDialog
{
// RXgNV
public:
	CSettingGeneralOtherDlg(CWnd* pParent = NULL);   // W̃RXgN^

// _CAO f[^
	//{{AFX_DATA(CSettingGeneralOtherDlg)
	enum { IDD = IDD_SETTING_GENERAL_OTHER };
	CButton	m_checkTaskTrayOnly;
	CButton	m_checkUseTaskTray;
	CEdit	m_autofetch_minute;
	CComboBox	m_def_account;
	CEdit	m_editor_path;
	//}}AFX_DATA


// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CSettingGeneralOtherDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CSettingGeneralOtherDlg)
	afx_msg void OnEditorRef();
	virtual BOOL OnInitDialog();
	virtual void OnOK();
	afx_msg void OnSettingGeneralUseTasktray();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_SETTINGGENERALOTHERDLG_H__2D070D89_4B2B_4B11_8A74_ADAFE9D50F74__INCLUDED_)
